@@ -7,14 +7,11 @@ import numpy as np
 from scipy.sparse.linalg import lsqr
 
 from pylops import LinearOperator
-from pylops.basicoperators import Diagonal, Identity
+from pylops.basicoperators import Diagonal, Identity, VStack
 from pylops.optimization.basesolver import Solver
 from pylops.optimization.basic import cgls
 from pylops.optimization.eigs import power_iteration
-from pylops.optimization.leastsquares import (
-    normal_equations_inversion,
-    regularized_inversion,
-)
+from pylops.optimization.leastsquares import regularized_inversion
 from pylops.utils import deps
 from pylops.utils.backend import get_array_module, get_module_name
 from pylops.utils.decorators import disable_ndarray_multiplication
@@ -328,6 +325,7 @@ class IRLS(Solver):
         epsR: float = 1e-10,
         epsI: float = 1e-10,
         tolIRLS: float = 1e-10,
+        warm: bool = False,
         kind: str = "data",
         show: bool = False,
     ) -> None:
@@ -345,12 +343,16 @@ class IRLS(Solver):
         epsR : :obj:`float`, optional
             Damping to be applied to residuals for weighting term
         epsI : :obj:`float`, optional
-            Tikhonov damping
+            Tikhonov damping (for ``kind="data"``) or L1 model damping
+            (for ``kind="datamodel"``)
         tolIRLS : :obj:`float`, optional
             Tolerance. Stop outer iterations if difference between inverted model
             at subsequent iterations is smaller than ``tolIRLS``
+        warm  : :obj:`bool`, optional
+            Warm start each inversion inner step with previous estimate (``True``) or not (``False``).
+            This only applies to ``kind="data"`` and ``kind="datamodel"``
         kind : :obj:`str`, optional
-            Kind of solver (``data`` or ``model``)
+            Kind of solver (``model``, ``data`` or ``datamodel``)
         show : :obj:`bool`, optional
             Display setup log
 
@@ -361,6 +363,7 @@ class IRLS(Solver):
         self.epsR = epsR
         self.epsI = epsI
         self.tolIRLS = tolIRLS
+        self.warm = warm
         self.kind = kind
         self.ncp = get_array_module(y)
         self.iiter = 0
@@ -371,8 +374,14 @@ class IRLS(Solver):
         elif self.kind == "model":
             self._step = self._step_model
             self.Iop = Identity(y.size, dtype=y.dtype)
+        elif self.kind == "datamodel":
+            self._step = self._step_data
+            # augment Op and y
+            self.Op = VStack([self.Op, epsI * Identity(self.Op.shape[1])])
+            self.epsI = 0.0  # as epsI is added to the augmented system already
+            self.y = np.hstack([self.y, np.zeros(self.Op.shape[1])])
         else:
-            raise NotImplementedError("kind must be model or data")
+            raise NotImplementedError("kind must be model, data or datamodel")
 
         # print setup
         if show:
@@ -381,9 +390,13 @@ class IRLS(Solver):
     def _step_data(self, x: NDArray, **kwargs_solver) -> NDArray:
         r"""Run one step of solver with L1 data term"""
         if self.iiter == 0:
-            # first iteration (unweighted least-squares)
-            x = normal_equations_inversion(
-                self.Op, self.y, None, epsI=self.epsI, **kwargs_solver
+            x = regularized_inversion(
+                self.Op,
+                self.y,
+                None,
+                x0=x if self.warm else None,
+                damp=self.epsI,
+                **kwargs_solver,
             )[0]
         else:
             # other iterations (weighted least-squares)
@@ -392,9 +405,15 @@ class IRLS(Solver):
             else:
                 self.rw = 1.0 / (self.ncp.abs(self.r) + self.epsR)
             self.rw = self.rw / self.rw.max()
-            R = Diagonal(self.rw)
-            x = normal_equations_inversion(
-                self.Op, self.y, [], Weight=R, epsI=self.epsI, **kwargs_solver
+            R = Diagonal(np.sqrt(self.rw))
+            x = regularized_inversion(
+                self.Op,
+                self.y,
+                None,
+                Weight=R,
+                x0=x if self.warm else None,
+                damp=self.epsI,
+                **kwargs_solver,
             )[0]
         return x
 
@@ -488,7 +507,7 @@ class IRLS(Solver):
         x: NDArray,
         nouter: int = 10,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
         **kwargs_solver,
     ) -> NDArray:
         r"""Run solver
@@ -501,7 +520,7 @@ class IRLS(Solver):
             Number of outer iterations.
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -569,8 +588,9 @@ class IRLS(Solver):
         epsI: float = 1e-10,
         tolIRLS: float = 1e-10,
         kind: str = "data",
+        warm: bool = False,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
         **kwargs_solver,
     ) -> NDArray:
         r"""Run entire solver
@@ -594,11 +614,14 @@ class IRLS(Solver):
         tolIRLS : :obj:`float`, optional
             Tolerance. Stop outer iterations if difference between inverted model
             at subsequent iterations is smaller than ``tolIRLS``
+        warm  : :obj:`bool`, optional
+            Warm start each inversion inner step with previous estimate (``True``) or not (``False``).
+            This only applies to ``kind="data"`` and ``kind="datamodel"``
         kind : :obj:`str`, optional
             Kind of solver (``data`` or ``model``)
         show : :obj:`bool`, optional
             Display setup log
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -621,6 +644,7 @@ class IRLS(Solver):
             epsR=epsR,
             epsI=epsI,
             tolIRLS=tolIRLS,
+            warm=warm,
             kind=kind,
             show=show,
         )
@@ -738,7 +762,6 @@ class OMP(Solver):
             Display setup log
 
         """
-        self.Op = LinearOperator(self.Op)
         self.y = y
         self.niter_outer = niter_outer
         self.niter_inner = niter_inner
@@ -849,7 +872,7 @@ class OMP(Solver):
         x: NDArray,
         cols: InputDimsLike,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
     ) -> Tuple[NDArray, InputDimsLike]:
         r"""Run solver
 
@@ -861,7 +884,7 @@ class OMP(Solver):
             Current list of chosen elements of vector x to be updated by a step of OMP
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -931,7 +954,7 @@ class OMP(Solver):
         sigma: float = 1e-4,
         normalizecols: bool = False,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
     ) -> Tuple[NDArray, int, NDArray]:
         r"""Run entire solver
 
@@ -954,7 +977,7 @@ class OMP(Solver):
             operator are expected to have highly varying norms.
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -1095,7 +1118,6 @@ class ISTA(Solver):
             + f"{costdata:10.3e}   {costdata + costreg:9.3e}  {xupdate:10.3e}"
         )
         print(msg)
-        pass
 
     def setup(
         self,
@@ -1217,10 +1239,8 @@ class ISTA(Solver):
         if alpha is not None:
             self.alpha = alpha
         elif not hasattr(self, "alpha"):
-            if not isinstance(self.Op, LinearOperator):
-                self.Op = LinearOperator(self.Op, explicit=False)
             # compute largest eigenvalues of Op^H * Op
-            Op1 = LinearOperator(self.Op.H * self.Op, explicit=False)
+            Op1 = self.Op.H * self.Op
             if get_module_name(self.ncp) == "numpy":
                 maxeig: float = np.abs(
                     Op1.eigs(
@@ -1340,7 +1360,7 @@ class ISTA(Solver):
         x: NDArray,
         niter: Optional[int] = None,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
     ) -> NDArray:
         r"""Run solver
 
@@ -1353,7 +1373,7 @@ class ISTA(Solver):
             provided in the setup call
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -1417,7 +1437,7 @@ class ISTA(Solver):
         decay: Optional[NDArray] = None,
         monitorres: bool = False,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
     ) -> Tuple[NDArray, int, NDArray]:
         r"""Run entire solver
 
@@ -1458,7 +1478,7 @@ class ISTA(Solver):
             Monitor that residual is decreasing
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -1623,7 +1643,7 @@ class FISTA(ISTA):
         x: NDArray,
         niter: Optional[int] = None,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
     ) -> NDArray:
         r"""Run solver
 
@@ -1636,7 +1656,7 @@ class FISTA(ISTA):
             provided in the setup call
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -2263,7 +2283,7 @@ class SplitBregman(Solver):
         self,
         x: NDArray,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
         show_inner: bool = False,
         **kwargs_lsqr,
     ) -> NDArray:
@@ -2275,7 +2295,7 @@ class SplitBregman(Solver):
             Current model vector to be updated by multiple steps of IRLS
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
@@ -2348,7 +2368,7 @@ class SplitBregman(Solver):
         tau: float = 1.0,
         restart: bool = False,
         show: bool = False,
-        itershow: List[int] = [10, 10, 10],
+        itershow: Tuple[int, int, int] = (10, 10, 10),
         show_inner: bool = False,
         **kwargs_lsqr,
     ) -> Tuple[NDArray, int, NDArray]:
@@ -2397,7 +2417,7 @@ class SplitBregman(Solver):
             be used in all iterations.
         show : :obj:`bool`, optional
             Display logs
-        itershow : :obj:`list`, optional
+        itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
