@@ -26,9 +26,10 @@ def irls(
     epsR: float = 1e-10,
     epsI: float = 1e-10,
     tolIRLS: float = 1e-10,
+    warm: bool = False,
     kind: str = "data",
     show: bool = False,
-    itershow: List[int] = [10, 10, 10],
+    itershow: Tuple[int, int, int] = (10, 10, 10),
     callback: Optional[Callable] = None,
     **kwargs_solver,
 ) -> Tuple[NDArray, int]:
@@ -68,11 +69,14 @@ def irls(
     tolIRLS : :obj:`float`, optional
         Tolerance. Stop outer iterations if difference between inverted model
         at subsequent iterations is smaller than ``tolIRLS``
+    warm  : :obj:`bool`, optional
+        Warm start each inversion inner step with previous estimate (``True``) or not (``False``).
+        This only applies to ``kind="data"`` and ``kind="datamodel"``
     kind : :obj:`str`, optional
-        Kind of solver (``data`` or ``model``)
+        Kind of solver (``model``, ``data`` or ``datamodel``)
     show : :obj:`bool`, optional
         Display logs
-    itershow : :obj:`list`, optional
+    itershow : :obj:`tuple`, optional
         Display set log for the first N1 steps, last N2 steps,
         and every N3 steps in between where N1, N2, N3 are the
         three element of the list.
@@ -109,6 +113,7 @@ def irls(
         epsR=epsR,
         epsI=epsI,
         tolIRLS=tolIRLS,
+        warm=warm,
         kind=kind,
         show=show,
         itershow=itershow,
@@ -125,7 +130,7 @@ def omp(
     sigma: float = 1e-4,
     normalizecols: bool = False,
     show: bool = False,
-    itershow: List[int] = [10, 10, 10],
+    itershow: Tuple[int, int, int] = (10, 10, 10),
     callback: Optional[Callable] = None,
 ) -> Tuple[NDArray, int, NDArray]:
     r"""Orthogonal Matching Pursuit (OMP).
@@ -156,7 +161,7 @@ def omp(
         operator are expected to have highly varying norms.
     show : :obj:`bool`, optional
         Display iterations log
-    itershow : :obj:`list`, optional
+    itershow : :obj:`tuple`, optional
         Display set log for the first N1 steps, last N2 steps,
         and every N3 steps in between where N1, N2, N3 are the
         three element of the list.
@@ -215,7 +220,7 @@ def ista(
     decay: Optional[NDArray] = None,
     monitorres: bool = False,
     show: bool = False,
-    itershow: List[int] = [10, 10, 10],
+    itershow: Tuple[int, int, int] = (10, 10, 10),
     callback: Optional[Callable] = None,
 ) -> Tuple[NDArray, int, NDArray]:
     r"""Iterative Shrinkage-Thresholding Algorithm (ISTA).
@@ -264,7 +269,7 @@ def ista(
         Monitor that residual is decreasing
     show : :obj:`bool`, optional
         Display logs
-    itershow : :obj:`list`, optional
+    itershow : :obj:`tuple`, optional
         Display set log for the first N1 steps, last N2 steps,
         and every N3 steps in between where N1, N2, N3 are the
         three element of the list.
@@ -341,7 +346,7 @@ def fista(
     decay: Optional[NDArray] = None,
     monitorres: bool = False,
     show: bool = False,
-    itershow: List[int] = [10, 10, 10],
+    itershow: Tuple[int, int, int] = (10, 10, 10),
     callback: Optional[Callable] = None,
 ) -> Tuple[NDArray, int, NDArray]:
     r"""Fast Iterative Shrinkage-Thresholding Algorithm (FISTA).
@@ -390,7 +395,7 @@ def fista(
             Monitor that residual is decreasing
     show : :obj:`bool`, optional
         Display iterations log
-    itershow : :obj:`list`, optional
+    itershow : :obj:`tuple`, optional
         Display set log for the first N1 steps, last N2 steps,
         and every N3 steps in between where N1, N2, N3 are the
         three element of the list.
@@ -583,7 +588,7 @@ def splitbregman(
     tau: float = 1.0,
     restart: bool = False,
     show: bool = False,
-    itershow: List[int] = [10, 10, 10],
+    itershow: Tuple[int, int, int] = (10, 10, 10),
     show_inner: bool = False,
     callback: Optional[Callable] = None,
     **kwargs_lsqr,
@@ -637,7 +642,7 @@ def splitbregman(
         the initial guess (``True``) or with the last estimate (``False``)
     show : :obj:`bool`, optional
         Display iterations log
-    itershow : :obj:`list`, optional
+    itershow : :obj:`tuple`, optional
             Display set log for the first N1 steps, last N2 steps,
             and every N3 steps in between where N1, N2, N3 are the
             three element of the list.
