@@ -1,7 +1,9 @@
 # isort: skip_file
 from .backend import *
 from .deps import *
-from .dottest import dottest
+from .dottest import *
 from .estimators import *
+from .metrics import *
 from .multiproc import *
-from .utils import Report
+from .utils import *
+from .typing import *
