@@ -1,4 +1,7 @@
-import warnings
+__all__ = ["dottest"]
+
+from typing import Optional
+
 import numpy as np
 
 from pylops.utils.backend import get_module, to_numpy
@@ -6,16 +9,15 @@ from pylops.utils.backend import get_module, to_numpy
 
 def dottest(
     Op,
-    nr=None,
-    nc=None,
-    rtol=1e-6,
-    complexflag=0,
-    raiseerror=True,
-    verb=False,
-    backend="numpy",
-    atol=1e-21,
-    tol=None,  # deprecated, use rtol
-):
+    nr: Optional[int] = None,
+    nc: Optional[int] = None,
+    rtol: float = 1e-6,
+    atol: float = 1e-21,
+    complexflag: int = 0,
+    raiseerror: bool = True,
+    verb: bool = False,
+    backend: str = "numpy",
+) -> bool:
     r"""Dot test.
 
     Generate random vectors :math:`\mathbf{u}` and :math:`\mathbf{v}`
@@ -33,7 +35,9 @@ def dottest(
         Number of columns of operator (i.e., elements in model)
     rtol : :obj:`float`, optional
         Relative dottest tolerance
-        .. versionadded:: 1.18.1
+    atol : :obj:`float`, optional
+        Absolute dottest tolerance
+        .. versionadded:: 2.0.0
     complexflag : :obj:`bool`, optional
         Generate random vectors with
 
@@ -51,17 +55,15 @@ def dottest(
     backend : :obj:`str`, optional
         Backend used for dot test computations (``numpy`` or ``cupy``). This
         parameter will be used to choose how to create the random vectors.
-    atol : :obj:`float`, optional
-        Absolute dottest tolerance
-        .. versionadded:: 1.18.1
-    tol : :obj:`float`, optional
-        Dottest tolerance
-        .. deprecated:: 2.0.0
-            Use ``rtol`` instead.
+
+    Returns
+    -------
+    passed : :obj:`bool`
+        Passed flag.
 
     Raises
     ------
-    ValueError
+    AssertionError
         If dot-test is not verified within chosen tolerances.
 
     Notes
@@ -78,14 +80,6 @@ def dottest(
         \mathbf{u}^H(\mathbf{Op}^H\mathbf{v})
 
     """
-    if tol is not None:
-        warnings.warn(
-            "tol will be deprecated in version 2.0.0, use rtol instead.",
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
-        rtol = tol
-
     ncp = get_module(backend)
 
     if nr is None:
@@ -131,7 +125,7 @@ def dottest(
         passed_status = "passed" if passed else "failed"
         msg = f"Dot test {passed_status}, v^H(Opu)={yy} - u^H(Op^Hv)={xx}"
         if not passed and raiseerror:
-            raise ValueError(msg)
+            raise AssertionError(msg)
         else:
             print(msg)
 
